import {
  ChangeDetectorRef,
  Component,
  EventEmitter,
  Input,
  Output,
} from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { SwalService } from 'src/app/components/advanced/sweetalert/sweetalert.component';
import Swal from 'sweetalert2';

export interface dataModel {
  check: boolean;
  code: string;
  period: string;
  year: string;
  startDate: string;
  endDate: string;
  status: string;
}

@Component({
  selector: 'app-define-document-form',
  templateUrl: './define-document-form.component.html',
  styleUrls: ['./define-document-form.component.scss'],
})
export class DefineDocumentFormComponent {
  [x: string]: any;
  @Output() sendGroupShow: EventEmitter<string> = new EventEmitter<string>();
  currentPage = 1;
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  search = '';
  numDataListChecked = 0;
  isDataListChecked = false;
  isDataListCheckedAll = false;
  dataList: dataModel[] = [
    {
      check: false,
      code: 'Y67P2',
      period: 'ช่วงเวลาที่ 2',
      year: '2567',
      startDate: '01-07-2567',
      endDate: '31-12-2567',
      status: '1',
    },
    {
      check: false,
      code: 'Y68P1',
      period: 'ช่วงเวลาที่ 1',
      year: '2568',
      startDate: '01-01-2568',
      endDate: '30-06-2568',
      status: '2',
    },
  ];
  dataSelect: dataModel = {
    check: false,
    code: '',
    period: '',
    year: '',
    startDate: '',
    endDate: '',
    status: '',
  };
  modalStatus: 'add' | 'edit' = 'add';
  constructor(
    private cdr: ChangeDetectorRef,
    private swalService: SwalService,
    private toastr: ToastrService
  ) {}

  onEdit() {
    this.sendGroupShow.emit('2');
  }

  dataListSelect(data?: dataModel) {
    this.dataSelect = data || {
      check: false,
      code: '',
      period: '',
      year: '',
      startDate: '',
      endDate: '',
      status: '',
    };
    this.cdr.detectChanges();
  }

  dataListFilter() {
    return this.dataList.filter((x) => {
      const match =
        x.code.includes(this.search) || x.period.includes(this.search);
      if (!match) x.check = false;
      return match;
    });
  }

  dataListCheck() {
    const dataCheck = this.dataListFilter();
    this.isDataListChecked = dataCheck.some((x) => x.check);
    this.isDataListCheckedAll = dataCheck.length
      ? dataCheck.every((x) => x.check)
      : false;
    this.numDataListChecked = dataCheck.filter((x) => x.check).length;
  }

  dataListCheckAll() {
    const selectAll = this.isDataListCheckedAll;
    this.dataList.forEach((x) => (x.check = selectAll));
    this.dataListCheck();
  }

  searchChange() {
    this.currentPage = 1;
    const filteredData = this.dataListFilter();
    this.page = Array.from(
      { length: Math.ceil(filteredData.length / 10) },
      (_, i) => i + 1
    );
    this.dataListCheck();
  }

  showSuccessDelete() {
    this.toastr.success('ลบข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  basicAlert3() {
    Swal.fire({
      iconHtml: '<i class="ri-file-upload-line text-center rounded-full !h-80px !w-80px !bg-success"></i>',
      title: 'ส่งออกเอกสาร',
      text: 'คุณต้องการส่งออกเอกสารฉบับนี้ใช่หรือไม่',
      showCancelButton: true,
      reverseButtons: true,
      confirmButtonText: 'ส่งออกเอกสาร',
      cancelButtonText: 'ย้อนกลับ',
      customClass: {
        actions:"!swal2-actions-mt-20px",
        icon: '!swal2-icon-no-border',
        confirmButton: '!swal2-button-bg-green',
      },
    }).then((result) => {
      if (result.isConfirmed) {
        Swal.fire({
          title: 'ส่งออกสำเร็จ!',
          text: 'เอกสารของคุณถูกส่งออกแล้ว',
          icon: 'success',
          confirmButtonColor: '#0162e8',
        });
      } else if (result.dismiss === Swal.DismissReason.cancel) {
        Swal.fire({
          title: 'ยกเลิก!',
          text: 'การส่งออกถูกยกเลิก',
          icon: 'error',
          confirmButtonColor: '#f43f5e',
        });
      }
    });
  }
}
